<?php
/*
 * Plugin Name: Gzip Compression
 * Description: Automatically enables Gzip compression by modifying the .htaccess file upon activation and removes the rules upon deactivation.
 * Version: 1.0
 * Author: Ryan Briscall
 * Copyright: Dekker Designs, 2025-01-08, All Rights Reserved
*/

if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly
}

/**
 * Add Gzip rules to the .htaccess file on plugin activation.
 */
function dd_gzipcompression_activate() {
	$path = ABSPATH;
	$htaccess_file = $path . '.htaccess';

	// Check if .htaccess exists; read its content or initialize as empty.
	$htaccess = file_exists($htaccess_file) ? @file_get_contents($htaccess_file) : "";

	// Define Gzip compression rules.
	$gzip_rules = "# BEGIN GzipCompression\n" .
		"<IfModule mod_deflate.c>\n" .
		"AddType x-font/woff .woff\n" .
		"AddType x-font/ttf .ttf\n" .
		"AddOutputFilterByType DEFLATE image/svg+xml\n" .
		"AddOutputFilterByType DEFLATE text/plain\n" .
		"AddOutputFilterByType DEFLATE text/html\n" .
		"AddOutputFilterByType DEFLATE text/xml\n" .
		"AddOutputFilterByType DEFLATE text/css\n" .
		"AddOutputFilterByType DEFLATE text/javascript\n" .
		"AddOutputFilterByType DEFLATE application/xml\n" .
		"AddOutputFilterByType DEFLATE application/xhtml+xml\n" .
		"AddOutputFilterByType DEFLATE application/rss+xml\n" .
		"AddOutputFilterByType DEFLATE application/javascript\n" .
		"AddOutputFilterByType DEFLATE application/x-javascript\n" .
		"AddOutputFilterByType DEFLATE application/x-font-ttf\n" .
		"AddOutputFilterByType DEFLATE x-font/ttf\n" .
		"AddOutputFilterByType DEFLATE application/vnd.ms-fontobject\n" .
		"AddOutputFilterByType DEFLATE font/opentype font/ttf font/eot font/otf\n" .
		"</IfModule>\n" .
		"# END GzipCompression\n";

	// Remove any existing GzipCompression block.
	$htaccess = preg_replace("/\s*\#\s?BEGIN\s?GzipCompression.*?#\s?END\s?GzipCompression\s*/s", "", $htaccess);

	// Append the new Gzip rules.
	$htaccess .= "\n" . $gzip_rules;

	// Write the updated .htaccess file.
	@file_put_contents($htaccess_file, $htaccess);
}
register_activation_hook(__FILE__, 'dd_gzipcompression_activate');

function dd_gzipcompression_deactivate() {
	$path = ABSPATH;
	$htaccess_file = $path . '.htaccess';

	if (file_exists($htaccess_file)) {
		// Read the .htaccess content.
		$htaccess = @file_get_contents($htaccess_file);

		// Remove the GzipCompression block.
		$htaccess = preg_replace("/\s*\#\s?BEGIN\s?GzipCompression.*?#\s?END\s?GzipCompression\s*/s", "", $htaccess);

		// Write the updated .htaccess file.
		@file_put_contents($htaccess_file, $htaccess);
	}
}
register_deactivation_hook(__FILE__, 'dd_gzipcompression_deactivate');

function dd_gzipcompression_uninstall() {
	dd_gzipcompression_deactivate();
}
register_uninstall_hook(__FILE__, 'dd_gzipcompression_uninstall');
